==> haskell-nothunks-0.2.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nothunks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 nothunks
version:              0.2.0
visibility:           public
id:                   nothunks-0.2.0-BjitQFAqA5VA02I4N0vE3O
key:                  nothunks-0.2.0-BjitQFAqA5VA02I4N0vE3O
license:              Apache-2.0
copyright:            2018-2024 Input Output Global Inc (IOG)
maintainer:           Marcin Szamotulski <coot@coot.me>
author:               IOG
synopsis:             Examine values for unexpected thunks
description:
    Long lived application data typically should not contain
    any thunks. This library can be used to examine values for
    unexpected thunks, which can then be used in assertions.
    This can be invaluable in avoiding memory leaks, or tracking
    down existing ones.

category:             Development
abi:                  8e7f18df0d5569b9d17e9ba04bf01f9d
exposed:              True
exposed-modules:      NoThunks.Class
import-dirs:          /usr/lib/ghc-9.2.8/site-local/nothunks-0.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/nothunks-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nothunks
hs-libraries:         HSnothunks-0.2.0-BjitQFAqA5VA02I4N0vE3O
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1 ghc-heap-9.2.8
    stm-2.5.0.2 text-1.2.5.0 time-1.11.1.1
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe

haddock-interfaces:   /usr/share/doc/haskell-nothunks/html/nothunks.haddock
haddock-html:         /usr/share/doc/haskell-nothunks/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nothunks-0.2.0-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nothunks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 nothunks
version:              0.2.0
visibility:           public
id:                   nothunks-0.2.0-J0sZLAQFYQ6ADKJxM9AY79
key:                  nothunks-0.2.0-J0sZLAQFYQ6ADKJxM9AY79
license:              Apache-2.0
copyright:            2018-2024 Input Output Global Inc (IOG)
maintainer:           Marcin Szamotulski <coot@coot.me>
author:               IOG
synopsis:             Examine values for unexpected thunks
description:
    Long lived application data typically should not contain
    any thunks. This library can be used to examine values for
    unexpected thunks, which can then be used in assertions.
    This can be invaluable in avoiding memory leaks, or tracking
    down existing ones.

category:             Development
abi:                  002316db7c247641d88ca56c1e468c84
exposed:              True
exposed-modules:      NoThunks.Class
import-dirs:          /usr/lib/ghc-9.2.8/site-local/nothunks-0.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/nothunks-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nothunks
hs-libraries:         HSnothunks-0.2.0-J0sZLAQFYQ6ADKJxM9AY79
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1 ghc-heap-9.2.8
    stm-2.5.0.2 text-1.2.5.0 time-1.11.1.1
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe

haddock-interfaces:   /usr/share/doc/haskell-nothunks/html/nothunks.haddock
haddock-html:         /usr/share/doc/haskell-nothunks/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
